%%%
%%% 2023-12-7. Nova de Hi
%%% 2023-12-9. bigindent option.
%%%
\ProvidesClass{wongoji}[2023/12/02 version 0.2 WONGOJI class]

\RequirePackage{l3keys2e}

\ExplSyntaxOn

\keys_define:nn { wongojipkg }
{
	200	.bool_set_inverse:N = \opt_four_bool,
	400	.bool_set:N = \opt_four_bool,
	bigindent 	.bool_set:N = \opt_bigindent_bool,
}

\keys_set:nn { wongojipkg }
{
	200 = true,
	400 = false,
	bigindent = false,
}

\ProcessKeysOptions { wongojipkg } 

\ExplSyntaxOff

\LoadClass[12pt]{oblivoir}

\newif\iftwohundred
\newif\ifbigIndent

\newcommand*\Xquoteindentbig {\bigIndenttrue}
\newcommand*\Xquoteindentsmall {\bigIndentfalse}

\ExplSyntaxOn

\bool_if:NTF \opt_bigindent_bool
{
	\bigIndenttrue
}
{
	\bigIndentfalse
}

\RequirePackage{fapapersize}
\bool_if:NTF \opt_four_bool
{
	\usefapapersize{210mm,297mm,20mm,\dimexpr190mm-40em+2pt\relax,25mm,80mm}
	\tl_set:Nn \bggraphic { wongojiwhite400 }
	\twohundredfalse
}
{
	\usefapapersize{210mm,148mm,20mm,\dimexpr190mm-40em+2pt\relax,20mm,30mm}
	\tl_set:Nn \bggraphic { wongojiwhite }
	\twohundredtrue
}

\ExplSyntaxOff

\RequirePackage{xcolor,ninecolors}
\RequirePackage{graphicx}
\graphicspath{{./}{./images}}
\RequirePackage{tzplot}
\usetikzlibrary{tikzmark}
\RequirePackage{ragged2e}
\RequirePackage{adjustbox}
\RequirePackage[normalem]{ulem}
\RequirePackage{oblivoir-misc}

\parindent=0pt

\newlength\pagematchdimen
\setlength\pagematchdimen{\dimexpr\textheight+33pt\relax}
\newlength\leftydimen
\setlength\leftydimen{2pt}
\copypagestyle{wongoji}{empty}
\makeoddfoot{wongoji}{%
    \begin{tikzpicture}[remember picture,overlay]
    \begin{pgfonlayer}{above}
%    \foreach \x in {0, 2.3, ..., 23}
%    	{ \tzline [red6]<-\leftydimen,\pagematchdimen> (0,-\x em)(40em,-\x em) }
%    \foreach \x in {2, 4.3, ..., 22.7}
%    	{ \tzline [red6]<-\leftydimen,\pagematchdimen> (0,-\x em)(40em,-\x em) }
%    \tzrectangle[red6,very thick]<-\leftydimen,\pagematchdimen>(0,0)(40em,-22.7em)
%    \foreach \i in {0,2,...,40}
%    	{
%    		\foreach \j in {0,2.3,...,22.7}
%    			{ \tzline+ [red6] <-\leftydimen,\pagematchdimen> (\i em,-\j em)(0,-2em) } 
%    	}
	\tznode[anchor=north west]<-\leftydimen-5pt,\pagematchdimen+4.5pt>(0,0){\includegraphics{\bggraphic}}
    \tznode[anchor=south east,red4]<-\leftydimen,\pagematchdimen>(40em,-1pt){\color{red4}\uline{\hangulfontspec{Zapfino.ttf}\footnotesize No. \color{magenta3}\thepage}}
    \end{pgfonlayer}
    \end{tikzpicture}
}{}{}

\AtBeginDocument{
\hangulfontspec{UnPenheulim.ttf}[interhchar=0.08em,WordSpace={2,0,0}]
\hanjafontspec{Noto Serif CJK KR}[Scale=.95,WordSpace={2,0,0}]
\def\XKinterhanjabreak{\hspace{2.1pt}}
\everyhangul{\allowbreak\fcolorbox{white}{white}{\adjustbox{width=1em}{#1}}}
\everyhanja{\allowbreak\fcolorbox{white}{white}{\adjustbox{width=1em}{#1}}}
\hangulmarks
\fontsize{1.33em}{1.72em}\selectfont
\RaggedRight\spaceskip=1.565em plus 0em minus 0em\xspaceskip=2.77em
\clubpenalty=0\widowpenalty=0\hyphenpenalty=0
\pagestyle{wongoji}
\everypar{\null\Xindent}
}

\newcommand*\Xindent{\hphantom{각}}
\newcommand*\Xnoindent{\hspace*{-1.5em}}
\newcommand*\Xbigskip{\vphantom{각}\par}
\newcommand*\comma{\:\allowbreak,\hspace{1.03em}}
\newcommand*\Xcomma{\rlap{\,,}\Xnewline}
\newcommand*\Xprd{\rlap{\:。}\allowbreak\hspace{3.1em}}
\let\Xaltprd\Xprd
\newcommand*\Xprdsym{。}
\newcommand*\Xb[1]{\fcolorbox{white}{white}{\minipage{1.1em}\centering#1\endminipage}}
\newcommand*\XXb[1]{\rlap{\Xb{#1}}}
\newcommand*\Xnewline{\newline \Xnoindent}
\newcommand*\Xellipsis{\mbox{\hangulfontspec{Noto Serif CJK KR}\kern-1pt\Xb{…}\Xb{…}}}

\RequirePackage{kslinematters}
\newlinecommand\dialog{\DialogFn{#1}}

\ExplSyntaxOn

\NewDocumentCommand \DialogFn { m }
{
	\tl_set:Nn \l_tmpa_tl { #1 }
	\tl_reverse:N \l_tmpa_tl
	\tl_set:Nx \l_tmpb_tl { \tl_head:N \l_tmpa_tl }
	\tl_set:Nx \l_tmpc_tl { \tl_tail:N \l_tmpa_tl }
	\tl_reverse:N \l_tmpc_tl
	
	\group_begin:
	\tl_set_eq:NN \Xprd \Xprdsym
	\begin{adjustwidth}{1.35em}{0pt}
	\ifbigIndent\Xindent\fi
	\,\Xb{“} \tl_use:N \l_tmpc_tl
	\str_case_e:nnTF { \l_tmpb_tl }
	{
		{ ? } { } { ! } { }
	}
	{
		\kern2pt \Xb { \tl_use:N \l_tmpb_tl } \Xb {”}
	}
	{
		\Xb{\kern2pt\tl_use:N \l_tmpb_tl\, ”}
	}
	\end{adjustwidth}
	\vspace{4pt}
	\group_end:
}

\NewDocumentCommand \hjparen { O{()} m }
{
	\tl_set:Nn \l_tmpl_tl { #1 }
	\tl_set:Nx \l_tmpm_tl { \tl_head:N \l_tmpl_tl }
	\tl_set:Nx \l_tmpn_tl { \tl_tail:N \l_tmpl_tl }
	
	\kern.15em\Xb{\l_tmpm_tl} #2 \Xb{\l_tmpn_tl}\kern.1em
}

\ExplSyntaxOff

\endinput
